<?php
/**
 * Plugin Name: V Pixel SMS WooCommerce
 * Description: SMS notifications for WooCommerce orders and user events
 * Version: 1.7.2
 * Author: V Pixel Pro
 */

namespace VPixelProSMS;

if (!defined('ABSPATH')) exit;

define("USE_ALL_DEVICES", 1);

class Plugin {
    private static $instance = null;
    private $options;
    private $order_statuses;

    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    private function __construct() {
        $this->order_statuses = wc_get_order_statuses();
        
        // Default settings
        $default_settings = array(
            'api_key' => '',
            'sender_id' => '0',
            'enabled' => 'yes',
            'debug_mode' => 'no',
            'device_options' => '1',
            'rand_devices' => 'yes',
            // User events
            'user_register_enabled' => 'no',
            'user_register_message' => 'Welcome {user_name}! Thank you for registering at {site_name}.',
            // Admin notifications
            'admin_notifications_enabled' => 'no',
            'admin_phone' => '',
            'admin_new_order_message' => 'New order #{order_id} received for {order_amount}'
        );

        // Add default messages for all order statuses
        foreach ($this->order_statuses as $status => $label) {
            $status = str_replace('wc-', '', $status);
            $default_settings["order_{$status}_enabled"] = 'no';
            $default_settings["order_{$status}_message"] = "Your order #{order_id} is now {status}";
        }

        $this->options = get_option('vpixel_pro_sms_settings', $default_settings);

        // Hooks
        add_action('woocommerce_order_status_changed', array($this, 'send_order_sms'), 10, 3);
        add_action('user_register', array($this, 'send_registration_sms'), 10, 1);
        add_action('woocommerce_new_order', array($this, 'send_admin_new_order_notification'), 10, 1);
        add_action('admin_menu', array($this, 'add_admin_menu'));
        add_action('admin_init', array($this, 'register_settings'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_scripts'));
    }

    public function enqueue_admin_scripts($hook) {
        if ('toplevel_page_vpixel-pro-sms' !== $hook) {
            return;
        }
        wp_enqueue_style('vpixel-pro-sms-admin', plugins_url('assets/css/admin.css', __FILE__));
    }

    public function add_admin_menu() {
        add_menu_page(
            'V Pixel Pro SMS',
            'V Pixel Pro SMS',
            'manage_options',
            'vpixel-pro-sms',
            array($this, 'settings_page'),
            'dashicons-phone',
            56
        );
    }

    public function register_settings() {
        register_setting(
            'vpixel_pro_sms_settings', 
            'vpixel_pro_sms_settings',
            array($this, 'sanitize_settings')
        );
    }

    public function sanitize_settings($input) {
        // Start with existing options to preserve all settings
        $sanitized = $this->options;

        // Only update fields that were actually submitted
        foreach ($input as $key => $value) {
            switch ($key) {
                // API Settings
                case 'api_key':
                case 'sender_id':
                    $sanitized[$key] = sanitize_text_field($value);
                    break;

                // Checkbox fields
                case 'enabled':
                case 'debug_mode':
                case 'user_register_enabled':
                case 'admin_notifications_enabled':
                    $sanitized[$key] = isset($value) ? 'yes' : 'no';
                    break;

                // Message templates
                case 'user_register_message':
                case 'admin_new_order_message':
                    $sanitized[$key] = wp_kses_post($value);
                    break;

                // Admin phone
                case 'admin_phone':
                    $sanitized[$key] = sanitize_text_field($value);
                    break;

                // Order status settings
                default:
                    if (strpos($key, 'order_') === 0) {
                        if (strpos($key, '_enabled') !== false) {
                            $sanitized[$key] = isset($value) ? 'yes' : 'no';
                        } else if (strpos($key, '_message') !== false) {
                            $sanitized[$key] = wp_kses_post($value);
                        }
                    }
                    break;
            }
        }

        // Ensure all order status settings exist
        foreach ($this->order_statuses as $status => $label) {
            $status = str_replace('wc-', '', $status);
            if (!isset($sanitized["order_{$status}_enabled"])) {
                $sanitized["order_{$status}_enabled"] = 'no';
            }
            if (!isset($sanitized["order_{$status}_message"])) {
                $sanitized["order_{$status}_message"] = "Your order #{order_id} is now {status}";
            }
        }

        return $sanitized;
    }

    public function settings_page() {
        if (!current_user_can('manage_options')) {
            return;
        }
        
        // Get current tab
        $current_tab = isset($_GET['tab']) ? sanitize_text_field($_GET['tab']) : 'api';
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            
            <h2 class="nav-tab-wrapper">
                <a href="?page=vpixel-pro-sms&tab=api" 
                   class="nav-tab <?php echo $current_tab === 'api' ? 'nav-tab-active' : ''; ?>">
                    API Settings
                </a>
                <a href="?page=vpixel-pro-sms&tab=orders" 
                   class="nav-tab <?php echo $current_tab === 'orders' ? 'nav-tab-active' : ''; ?>">
                    Order Notifications
                </a>
                <a href="?page=vpixel-pro-sms&tab=users" 
                   class="nav-tab <?php echo $current_tab === 'users' ? 'nav-tab-active' : ''; ?>">
                    User Registration
                </a>
                <a href="?page=vpixel-pro-sms&tab=admin" 
                   class="nav-tab <?php echo $current_tab === 'admin' ? 'nav-tab-active' : ''; ?>">
                    Admin Notifications
                </a>
            </h2>

            <form action="options.php" method="post">
                <?php
                settings_fields('vpixel_pro_sms_settings');
                
                echo '<div class="tab-content">';
                
                switch($current_tab) {
                    case 'orders':
                        echo '<h3>Order Status Notifications</h3>';
                        echo '<table class="form-table">';
                        foreach ($this->order_statuses as $status => $label) {
                            $status = str_replace('wc-', '', $status);
                            echo '<tr><th scope="row">' . esc_html($label) . '</th>';
                            echo '<td>';
                            echo '<label><input type="checkbox" name="vpixel_pro_sms_settings[order_' . esc_attr($status) . '_enabled]" value="yes" ' . 
                                 checked($this->options['order_' . $status . '_enabled'], 'yes', false) . '> Enable</label>';
                            echo '<br><br>';
                            echo '<textarea name="vpixel_pro_sms_settings[order_' . esc_attr($status) . '_message]" rows="3" class="large-text">' . 
                                 esc_textarea($this->options['order_' . $status . '_message']) . '</textarea>';
                            echo '<br><small>Available variables: {order_id}, {status}, {order_amount}, {billing_phone}</small>';
                            echo '</td></tr>';
                        }
                        echo '</table>';
                        break;

                    case 'users':
                        echo '<h3>User Registration Settings</h3>';
                        echo '<table class="form-table">';
                        echo '<tr><th scope="row">Enable Registration SMS</th>';
                        echo '<td><input type="checkbox" name="vpixel_pro_sms_settings[user_register_enabled]" value="yes" ' . 
                             checked($this->options['user_register_enabled'], 'yes', false) . '></td></tr>';
                        echo '<tr><th scope="row">Message Template</th>';
                        echo '<td><textarea name="vpixel_pro_sms_settings[user_register_message]" rows="3" class="large-text">' . 
                             esc_textarea($this->options['user_register_message']) . '</textarea>';
                        echo '<br><small>Available variables: {user_name}, {site_name}</small></td></tr>';
                        echo '</table>';
                        break;

                    case 'admin':
                        echo '<h3>Admin Notification Settings</h3>';
                        echo '<table class="form-table">';
                        echo '<tr><th scope="row">Enable Admin Notifications</th>';
                        echo '<td><input type="checkbox" name="vpixel_pro_sms_settings[admin_notifications_enabled]" value="yes" ' . 
                             checked($this->options['admin_notifications_enabled'], 'yes', false) . '></td></tr>';
                        echo '<tr><th scope="row">Admin Phone Number</th>';
                        echo '<td><input type="text" name="vpixel_pro_sms_settings[admin_phone]" value="' . 
                             esc_attr($this->options['admin_phone']) . '" class="regular-text"></td></tr>';
                        echo '<tr><th scope="row">New Order Message</th>';
                        echo '<td><textarea name="vpixel_pro_sms_settings[admin_new_order_message]" rows="3" class="large-text">' . 
                             esc_textarea($this->options['admin_new_order_message']) . '</textarea>';
                        echo '<br><small>Available variables: {order_id}, {order_amount}</small></td></tr>';
                        echo '</table>';
                        break;

                    default: // 'api' tab
                        echo '<h3>API Configuration</h3>';
                        echo '<table class="form-table">';
                        echo '<tr><th scope="row">API Key</th>';
                        echo '<td><input type="text" name="vpixel_pro_sms_settings[api_key]" value="' . 
                             esc_attr($this->options['api_key']) . '" class="regular-text"></td></tr>';
                        echo '<tr><th scope="row">Sender ID</th>';
                        echo '<td><input type="text" name="vpixel_pro_sms_settings[sender_id]" value="' . 
                             esc_attr($this->options['sender_id']) . '" class="regular-text"></td></tr>';
                        echo '<tr><th scope="row">Enable SMS Service</th>';
                        echo '<td><input type="checkbox" name="vpixel_pro_sms_settings[enabled]" value="yes" ' . 
                             checked($this->options['enabled'], 'yes', false) . '></td></tr>';
                        echo '<tr><th scope="row">Debug Mode</th>';
                        echo '<td><input type="checkbox" name="vpixel_pro_sms_settings[debug_mode]" value="yes" ' . 
                             checked($this->options['debug_mode'], 'yes', false) . '></td></tr>';
                        echo '</table>';
                        break;
                }
                
                echo '</div>';
                submit_button('Save Settings');
                ?>
            </form>

            <?php if ($this->options['debug_mode'] === 'yes'): ?>
                <div class="debug-log">
                    <h3>Debug Log</h3>
                    <textarea readonly rows="10" class="large-text code">
                        <?php echo esc_textarea($this->get_debug_log()); ?>
                    </textarea>
                </div>
            <?php endif; ?>
        </div>
        <?php
    }

    public function send_order_sms($order_id, $old_status, $new_status) {
        $this->log("Order status change detected:");
        $this->log("Order ID: " . $order_id);
        $this->log("Old Status: " . $old_status);
        $this->log("New Status: " . $new_status);

        if ($this->options['enabled'] !== 'yes') {
            $this->log("SMS service is disabled");
            return;
        }

        $status_key = "order_{$new_status}_enabled";
        $message_key = "order_{$new_status}_message";

        $this->log("Checking status key: " . $status_key);
        $this->log("Status enabled?: " . ($this->options[$status_key] ?? 'not set'));

        if (!isset($this->options[$status_key]) || $this->options[$status_key] !== 'yes') {
            $this->log("SMS for this status is disabled");
            return;
        }

        $order = wc_get_order($order_id);
        if (!$order) {
            $this->log("Could not find order with ID: " . $order_id);
            return;
        }

        // Get clean values without HTML
        $order_amount = strip_tags($order->get_formatted_order_total());
        $status_label = strip_tags($this->order_statuses['wc-' . $new_status]);
        $phone = $order->get_billing_phone();

        $this->log("Order details:");
        $this->log("Amount: " . $order_amount);
        $this->log("Status Label: " . $status_label);
        $this->log("Phone: " . $phone);

        $message = str_replace(
            array(
                '{order_id}',
                '{status}',
                '{order_amount}',
                '{billing_phone}'
            ),
            array(
                $order_id,
                $status_label,
                $order_amount,
                $phone
            ),
            $this->options[$message_key]
        );

        $this->log("Prepared message: " . $message);
        $this->send_sms($phone, $message);
    }

    public function send_registration_sms($user_id) {
        if ($this->options['enabled'] !== 'yes' || $this->options['user_register_enabled'] !== 'yes') {
            return;
        }

        $user = get_userdata($user_id);
        $phone = get_user_meta($user_id, 'billing_phone', true);

        if (!$phone) return;

        $message = str_replace(
            array('{user_name}', '{site_name}'),
            array($user->display_name, get_bloginfo('name')),
            $this->options['user_register_message']
        );

        $this->send_sms($phone, $message);
    }

    public function send_admin_new_order_notification($order_id) {
        if ($this->options['enabled'] !== 'yes' || 
            $this->options['admin_notifications_enabled'] !== 'yes' || 
            empty($this->options['admin_phone'])) {
            return;
        }

        $order = wc_get_order($order_id);
        if (!$order) return;

        // Get clean order amount without HTML
        $order_amount = strip_tags($order->get_formatted_order_total());

        $message = str_replace(
            array('{order_id}', '{order_amount}'),
            array($order_id, $order_amount),
            $this->options['admin_new_order_message']
        );

        $this->send_sms($this->options['admin_phone'], $message);
    }

    private function send_sms($to, $message) {
        if (empty($to) || empty($message)) {
            $this->log("Error: Empty phone number or message");
            return false;
        }

        $api_key = $this->options['api_key'];
        if (empty($api_key)) {
            $this->log("Error: API key not configured");
            return false;
        }

        try {
            $this->log("Starting SMS send process");
            
            $url = 'https://sms.vpixelpro.com/services/send.php';
            
            // Format according to working implementation
            $postData = array(
                'number' => $to,
                'message' => $message,
                'key' => $api_key,
                'devices' => $this->options['sender_id'] ?: 0, // Use sender_id as device ID, default to 0
            );

            $this->log("Post Data: " . print_r($postData, true));

            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($postData));
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            
            $response = curl_exec($ch);
            $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
            
            $this->log("HTTP Response Code: " . $httpCode);
            $this->log("Raw Response: " . $response);

            if (curl_errno($ch)) {
                $this->log("cURL Error: " . curl_error($ch));
                curl_close($ch);
                return false;
            }
            
            curl_close($ch);

            if ($httpCode == 200) {
                $json = json_decode($response, true);
                if ($json == false) {
                    if (empty($response)) {
                        $this->log("Error: Missing data in request");
                        return false;
                    } else {
                        $this->log("Error: " . $response);
                        return false;
                    }
                } else {
                    if ($json["success"]) {
                        $this->log("SMS sent successfully!");
                        return true;
                    } else {
                        $error = isset($json["error"]["message"]) ? $json["error"]["message"] : 'Unknown error';
                        $this->log("API Error: " . $error);
                        return false;
                    }
                }
            } else {
                $this->log("HTTP Error Code: " . $httpCode);
                return false;
            }

        } catch (Exception $e) {
            $this->log("Exception: " . $e->getMessage());
            return false;
        }
    }

    private function log($message) {
        if ($this->options['debug_mode'] !== 'yes') {
            return;
        }

        $log_file = WP_CONTENT_DIR . '/vpixel-sms-debug.log';
        $timestamp = current_time('mysql');
        error_log("[{$timestamp}] {$message}\n", 3, $log_file);
    }

    public function get_debug_log() {
        $log_file = WP_CONTENT_DIR . '/vpixel-sms-debug.log';
        return file_exists($log_file) ? file_get_contents($log_file) : 'No debug logs found.';
    }
}

// Initialize plugin
add_action('plugins_loaded', function() {
    if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
        Plugin::get_instance();
    }
});
